@@ -1,8 +1,8 @@
 `grad.desc` <- function(FUN = function(x, y) x^2 + 2 * 
     y^2, rg = c(-3, -3, 3, 3), init = c(-3, 3), gamma = 0.05, 
-    tol = 0.001, len = 50, interact = FALSE, control = ani.control(interval = 0.1), 
-    ...) {
-    control = checkargs(control, ...)
+    tol = 0.001, len = 50, interact = FALSE) {
+    nmax = ani.options("nmax")
+    interval = ani.options("interval")
     op = par(mar = c(2.5, 2, 2, 0.2), cex.axis = 0.8, cex.main = 1, 
         cex.lab = 0.8, mgp = c(1.5, 0.5, 0), tcl = -0.3)
     x = seq(rg[1], rg[3], length = len)
@@ -22,7 +22,7 @@
     newxy = xy - gamma * attr(grad(xy[1], xy[2]), "gradient")
     gap = abs(FUN(newxy[1], newxy[2]) - FUN(xy[1], xy[2]))
     i = 1
-    while (gap > tol & i <= control$nmax) {
+    while (gap > tol & i <= nmax) {
         contour(x, y, z, col = "red", xlab = nms[1], ylab = nms[2], 
             main = eval(substitute(expression(z == x), list(x = body(FUN)))))
         xy = rbind(xy, newxy[i, ])
@@ -32,11 +32,10 @@
             2], length = par("din")[1] / 50, col = "blue")
         gap = abs(FUN(newxy[i + 1, 1], newxy[i + 1, 2]) - FUN(xy[i + 
             1, 1], xy[i + 1, 2]))
-        if (control$saveANI) 
-            savePNG(n = i, width = control$width, height = control$height)
-        else Sys.sleep(control$interval)
+        Sys.sleep(interval)
         i = i + 1
     }
+    ani.options(nmax = i -1)
     par(op)
     invisible(list(par = newxy[i - 1, ], value = FUN(newxy[i - 
         1, 1], newxy[i - 1, 2]), iter = i - 1, gradient = grad, 
